==> nextcloud-23.0.9.tgz: nextcloud/apps/viewer/l10n/sl.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Pregledovalnik",
    "Simple file viewer with slideshow for media" : "Enostaven pregledovalnik datotek z možnostjo predstavitve",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Pokažite najnovejše fotografije in posnetke s počitnic kot v filmih, pokažite kakšno stran novega romana neposredno iz oblaka, izberite najboljše iz zbirke v neposrednem predogledu priljubljenih datotek in še veliko, veliko več!",
    "Your browser does not support audio." : "Spletni brskalnik ne podpira možnosti predvajanja zvoka.",
    "Error loading {name}" : "Prišlo je do napake med nalaganjem {name}",
    "Unsaved changes" : "Neshranjene spremembe",
    "Your browser does not support videos." : "Spletni brskalnik ne podpira predvajanja video posnetkov.",
    "Edit" : "Uredi",
    "Open sidebar" : "Odpri bočno okno",
    "Download" : "Prejmi",
    "Delete" : "Odstrani",
    "There is no plugin available to display this file type" : "Ni vstavka, ki omogoča prikaz te vrste datotek",
    "View" : "Poglej",
    "Name" : "Ime",
    "Save" : "Shrani",
    "Back" : "Nazaj",
    "Loading …" : "Poteka nalaganje …",
    "Reset" : "Ponastavi",
    "Cancel" : "Prekliči",
    "Continue" : "Nadaljuj",
    "Undo" : "Razveljavi",
    "Redo" : "Ponovno uveljavi",
    "Zoom in" : "Približaj",
    "Draw" : "Risba",
    "Original" : "Izvorno",
    "Custom" : "Po meri",
    "Value" : "Vrednost",
    "Image" : "Slika",
    "Line" : "Črtni diagram",
    "Text" : "Besedilo",
    "Size" : "Višina",
    "Position" : "Položaj",
    "Extension" : "Pripona",
    "Name is required." : "Ime mora biti vpisano.",
    "Quality" : "Kakovost"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-23.0.12p0.tgz: nextcloud/apps/viewer/l10n/sl.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Pregledovalnik",
    "Simple file viewer with slideshow for media" : "Enostaven pregledovalnik datotek z možnostjo predstavitve",
    "Your browser does not support audio." : "Spletni brskalnik ne podpira možnosti predvajanja zvoka.",
    "Error loading {name}" : "Prišlo je do napake med nalaganjem {name}",
    "Image saved" : "Slika je shranjena.",
    "Unsaved changes" : "Neshranjene spremembe",
    "Your browser does not support videos." : "Spletni brskalnik ne podpira predvajanja video posnetkov.",
    "Edit" : "Uredi",
    "Open sidebar" : "Odpri bočno okno",
    "Download" : "Prejmi",
    "Delete" : "Odstrani",
    "There is no plugin available to display this file type" : "Ni vstavka, ki omogoča prikaz te vrste datotek",
    "View" : "Poglej",
    "Name" : "Ime",
    "Save" : "Shrani",
    "Back" : "Nazaj",
    "Loading …" : "Poteka nalaganje …",
    "Reset" : "Ponastavi",
    "Cancel" : "Prekliči",
    "Continue" : "Nadaljuj",
    "Undo" : "Razveljavi",
    "Redo" : "Ponovno uveljavi",
    "Zoom in" : "Približaj",
    "Draw" : "Risba",
    "Original" : "Izvorno",
    "Custom" : "Po meri",
    "Landscape" : "Pokrajina",
    "Portrait" : "Portret",
    "Value" : "Vrednost",
    "Image" : "Slika",
    "Line" : "Črtni diagram",
    "Text" : "Besedilo",
    "Size" : "Višina",
    "Position" : "Položaj",
    "Extension" : "Pripona",
    "Name is required." : "Ime mora biti vpisano.",
    "Quality" : "Kakovost",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Pokažite najnovejše fotografije in posnetke s počitnic kot v filmih, pokažite kakšno stran novega romana neposredno iz oblaka, izberite najboljše iz zbirke v neposrednem predogledu priljubljenih datotek in še veliko, veliko več!"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
